@@ -43,7 +43,9 @@
 #' @param verbose Logical. Prints a graphical progress bar that tracks the
 #' creation of null matrices. Useful for conservative null models on large
 #' and/or sparse data.
-#' @return A data.frame containing the test statistic (turnover), z-value (z), p-value (pval), mean (simulatedMean) and variance (simulatedVariance) of simulations, and randomization method (method)
+#' @param seed seed for simulating the null model. Null matrices should be repeatable.
+#' @return A data.frame containing the test statistic (turnover), z-value (z), p-value (pval), 
+#' mean (simulatedMean) and variance (simulatedVariance) of simulations, and randomization method (method)
 #'
 #' @author Tad Dallas
 #' @export
@@ -64,24 +66,29 @@
 #' turnover.intmat <- Turnover(intmat, method='r1', sims=100, scores=1, binary=TRUE)
 #'
 
-Turnover <-function(comm ,method="r1" ,sims=1000 ,scores=1, order=TRUE, allowEmpty=FALSE, binary=TRUE, verbose=FALSE){
-
- if(order){comm = OrderMatrix(comm, scores = scores, binary = binary)}
- for(i in 1:ncol(comm)) {
-   comm[min(which(comm[,i] == 1)):max(which(comm[,i] == 1)), i] <- 1
- }
-
- turnover <- function(web){
-  D <- designdist(web, method = "(A-J)*(B-J)", terms = "minimum")
-  return(sum(D))
- }
-
- statistic <- turnover(comm)
- nulls <- NullMaker(comm = comm, sims = sims, method = method,
-        allowEmpty = allowEmpty, verbose = verbose, ordinate=order)
- simstat <- as.numeric(lapply(nulls,turnover))
- varstat <- sd(simstat)
- z <- (mean(simstat)-statistic)/(varstat)
- pval <- 2*pnorm(-abs(z))
- return(data.frame(turnover=statistic, z=z,pval=pval, simulatedMean=mean(simstat), simulatedVariance=varstat, method=method))
+Turnover = function (comm, method = "r1", sims = 1000, 
+  scores = 1, order = TRUE, allowEmpty = FALSE, 
+  binary = TRUE, verbose = FALSE, seed=1){
+    if (order) {
+        comm = OrderMatrix(comm, scores = scores, binary = binary)
+    }
+    for (i in 1:ncol(comm)) {
+        comm[min(which(comm[, i] == 1)):max(which(comm[, i] == 
+            1)), i] <- 1
+    }
+    turnover <- function(web) {
+        D <- designdist(web, method = "(A-J)*(B-J)", terms = "minimum")
+        return(sum(D))
+    }
+    statistic <- turnover(comm)
+    nulls <- NullMaker(comm = comm, sims = sims, method = method, 
+        allowEmpty = allowEmpty, verbose = verbose, ordinate = order)
+    simstat <- as.numeric(lapply(nulls, turnover))
+    varstat <- sd(simstat)
+    z <- (mean(simstat) - statistic)/(varstat)
+    pval <- 2 * pnorm(-abs(z))
+    return(data.frame(turnover = statistic, z = z, pval = pval, 
+        simulatedMean = mean(simstat), simulatedVariance = varstat, 
+        method = method))
 }
+
